@@ -48,7 +48,7 @@ class _Workbook:
             sheet.layout.kwargs.update(sheet.kwargs)
             self._set_worksheet_properties(sheet.layout, sheet.name)
         self.writer.save()
-        self.writer.close()
+
 
     def _write(self, exhibit, sheet, start_row=0, start_col=0):
         """
@@ -438,7 +438,7 @@ class Series(Title):
     def _default_format(self):
         base_formats = copy.deepcopy(settings['base_formats'])
         return [base_formats.get(
-                    str(self.data[0].dtype), base_formats['object'])
+                    str(self.data.iloc[0].dtype), base_formats['object'])
                 ] * len(self.data)
 
 
@@ -461,10 +461,10 @@ class Image(_XLCBase):
     """
 
     def __init__(self, data, width=1, height=1, formats={}, *args, **kwargs):
-        if data.__class__.__name__=='AxesSubplot':
-            inch_to_row = 0.01431127
-            inch_to_col = 0.077469335
-            img_shape = data.get_figure().get_size_inches()
+        if data.__class__.__name__ in ['AxesSubplot', 'Figure']:
+            #inch_to_row = 0.01431127
+            #inch_to_col = 0.077469335
+            #img_shape = data.get_figure().get_size_inches()
             imgdata = BytesIO()
             data.get_figure().savefig(imgdata, format="png")
             data = '_.png'
@@ -586,11 +586,11 @@ class DataFrame(_XLCBase):
             idx = self.data.index.to_frame().dtypes
             idx.index = [self.data.columns.name]
         else:
-            idx = pd.Series()
+            idx = pd.Series(dtype='object')
         cols = self.data.dtypes.append(idx)
         self.formats = {
             k: self.base_formats.get(v, self.base_formats['object'])
-            for k, v in dict(cols).items()}
+            for k, v in dict(zip(cols.index, cols.values)).items()}
         if type(formats) is list:
             self.formats.update(dict(zip(self.data.columns, formats)))
         elif type(formats) is str:
@@ -738,7 +738,7 @@ class Row(_Container):
             return self._row_heights
         data = np.array(
             [item.row_heights for item in self.args
-             if item.__class__.__name__ not in ['Title']])
+             if item.__class__.__name__ not in ['Title', 'Image']])
         lens = np.array([len(i) for i in data])
         mask = np.arange(lens.max()) < lens[:,None]
         out = np.zeros(mask.shape, dtype=data.dtype)
@@ -826,7 +826,7 @@ class Column(_Container):
 
     @row_heights.setter
     def row_heights(self, value):
-        self._row_heights = row_heights
+        self._row_heights = value
 
     def _get_html(self, my_height=100, my_width=100):
         direction = ''
@@ -926,7 +926,10 @@ class Sheet(_XLCBase):
     def __init__(self, name, layout, **kwargs):
         self.name = name
         self.kwargs = kwargs
-        self.layout = layout
+        if type(layout) is Image:
+            self.layout = Column(layout)
+        else:
+            self.layout = layout
         self.kwargs = kwargs
         self.column_widths = self.layout.column_widths
         self.row_heights = self.layout.row_heights
